@@ -18,7 +18,7 @@ class Instrument:
     tencent_addr = "https://market-data-1302861777.cos.ap-shanghai.myqcloud.com/"
     public_addr = "public/promisedland/"
 
-    def __init__(self, dt:str, morning:boolean = False):
+    def __init__(self, dt:str, morning:boolean = False, suffix:str='com'):
         """
         Returns an instance of Instrument class for instrument.db
 
@@ -26,7 +26,7 @@ class Instrument:
         ----------
         dt: date string for an instrument
         morning: set True for instrument_%Y%m%d_8am.db
-                 set False for instrument_%Y%m%d_prod.db
+                 set False for instrument_%Y%m%d_com.db
                  default is False
 
         Raises
@@ -41,6 +41,7 @@ class Instrument:
         """
         self.dt = Holidays.to_datetime(dt)
         self.morning = morning
+        self.suffix = suffix
         self._cache_instrument_db()
 
     def __del__(self):
@@ -61,7 +62,7 @@ class Instrument:
         if self.morning:
             remote_db_name = f"instrument_{dt_str}_8am.db"
         else:
-            remote_db_name = f"instrument_{dt_str}_prod.db"
+            remote_db_name = f"instrument_{dt_str}_{self.suffix}.db"
         local_db_name = f"tmp_{remote_db_name}"
         remote_url = f"{self.tencent_addr}{self.public_addr}{sub_dir}{remote_db_name}"
         if not os.path.exists(local_db_name):
@@ -109,7 +110,7 @@ class Instrument:
             13	IF2108	0.0	NaN	2021-08-20	300
             14	IF2203	0.0	NaN	2022-03-18	300
             15	IF2110	0.0	NaN	2021-10-15	300
-            948 rows × 5 columns
+            948 rows x 5 columns
         """
         conn = sqlite3.connect(self.cache)
         cur = conn.cursor()
