@@ -23,10 +23,6 @@ class TestPitrading(unittest.TestCase):
 
     def test_000_something(self):
         """Test something."""
-        ds = Holidays.to_datetime('20220702')
-        while ds <= Holidays.to_datetime('20220722'):
-            if Holidays.tradingday(ds):
-                Instrument(ds.strftime('%Y%m%d'), morning=True).get_tradable_contracts(prefix='IM')
-            ds += timedelta(days=10)
+        Instrument('20220726', suffix='csi').get_contract_mapping()
             
         
\ No newline at end of file
